# magicgui.widgets._bases

```{eval-rst}
.. currentmodule:: magicgui.widgets._bases

.. automodule:: magicgui.widgets._bases

.. autosummary::
   :nosignatures:
   :toctree: ../_autosummary

   Widget
   ValueWidget
   ButtonWidget
   RangedWidget
   TransformedRangedWidget
   SliderWidget
   CategoricalWidget
   ContainerWidget
```
